@@ -21,6 +21,7 @@
 #include "chxj_qr_code.h"
 #include "chxj_cookie.h"
 #include "chxj_encoding.h"
+#include "chxj_str_util.h"
 #include "chxj_buffered_write.h"
 
 #define GET_CHTML10(X) ((chtml10_t*)(X))
@@ -1986,7 +1987,7 @@ s_chtml10_start_input_tag(void *pdoc, Node *node)
 
   if (value && *value != 0) {
     W10_L(" value=\"");
-    W10_V(value);
+    W10_V(chxj_add_slash_to_doublequote(doc->pool,value));
     W10_L("\"");
   }
 
